#
# spec file for package whipper
#
# Copyright (c) 2017 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           whipper
Version:        0.7.3
Release:        bp153.1.15
License:        GPL-3.0+
Summary:        A CD ripper aiming for accuracy over speed
Url:            https://github.com/JoeLametta/whipper/
Group:          Productivity/Multimedia/CD/Grabbers
Source0:        https://github.com/JoeLametta/whipper/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         whipper-fix-appstream-file-path.patch
BuildRequires:  fdupes
BuildRequires:  libsndfile-devel
BuildRequires:  python2-gobject
BuildRequires:  python2-setuptools
BuildRequires:  python-xml

# nb: there is a difference between cd-paranoia [we want] and
#     cdparanoia [we don't]
Requires:       cd-paranoia >= 10.2
Requires:       cdrdao
Requires:       gobject-introspection
Requires:       python2-gobject
Requires:       python2-musicbrainzngs
Requires:       python2-mutagen
Requires:       python-CDDB
Requires:       python2-requests
Requires:       python-pycdio >= 0.20
Requires:       libcdio16 <= 0.94
Requires:       flac
Requires:       sox

Conflicts:      morituri
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Whipper is an audio CD ripper that aims for accuracy over speed. It
automatically tags tracks using MusicBrainz data, takes drive offsets into
account, supports AccurateRip, and can rip certain hidden tracks.
It is written in Python 2. Whipper was forked from the Morituri project,
after Morituri development halted.

%prep
%setup -q
%patch0 -p1

%build
make -C src CFLAGS='-std=c99 %{optflags}' CC=gcc PREFIX=%{_prefix}

%install
make -C src CFLAGS='-std=c99 %{optflags}' CC=gcc PREFIX=%{_prefix} DESTDIR=%{buildroot} install
python2 setup.py install -O2 \
  --root=%{buildroot} \
  --prefix=%{_prefix} \
  --exec-prefix=%{_exec_prefix} \
  --install-data=%{_datadir}

find %{buildroot}%{python_sitelib} -name '*.pyc' -exec rm -vf '{}' \+
%fdupes %{buildroot}%{python_sitelib}/

%files
%doc CHANGELOG.md README
%license LICENSE
%{_bindir}/accuraterip-checksum
%{_bindir}/%{name}
%{python_sitelib}/whipper/
%{python_sitelib}/%{name}-%{version}-py*.egg-info/
%{_datadir}/metainfo/com.github.whipper_team.Whipper.metainfo.xml

%changelog
* Tue Jan  8 2019 mardnh@gmx.de
- Update from 0.7.0 to 0.7.3
  Fixed bugs:
  * UnicodeEncodeError: 'ascii' codec can't encode characters in
    position 17-18: ordinal not in range(128)
  * Error when parsing log file due to left pad track number #340
  * Failing AccurateRipResponse tests #333
  * CRITICAL:whipper.command.cd:output directory is a finished
    rip output directory #287
  * Possible HTOA error #281
  * Disc template KeyError #279
  * Enhanced CD causes computer to freeze. #256
  * pycdio & libcdio issues #238
  * Unicode issues #215
  * whipper offset find exception #208
  Closed issues:
  * WARNING:whipper.common.program:network error: NetworkError()
  * Write musicbrainz_discid tag when disc is unknown #280
  * Write .toc files in addition to .cue files to support cdrdao
    and non-compliant .cue sheets #214
  Merged pull requests:
  * Discover plugins in system directories too #348
  * Avoid zero padding in logger track numbers #341
  * Update failing AccurateRipResponse tests #334
  * Raise exception when cdparanoia can't read any frames #328
  * Prevent exception in offset find #327
  * Fix template validation error #325
  * Fix UnicodeEncodeError with non ASCII MusicBrainz's catalog
    numbers #323
  * Raise exception if template has invalid variables #322
  * Preserve ToC file generated by cdrdao #321
- Add patch:
  * whipper-fix-appstream-file-path.patch
* Thu Jun  7 2018 sknorr@suse.com
- Update from 0.4.2 to 0.7.0
- Changes: https://github.com/JoeLametta/whipper/releases
- Implemented enhancements:
  - Simple message while reading TOC (gh#JoeLametta/whipper#257)
  - Various ripping issues (gh#JoeLametta/whipper#179)
  - Small readme cleanups (gh#JoeLametta/whipper#250)
  - Remove debug commands, add mblookup command
    (gh#JoeLametta/whipper#249)
  - remove -T/--toc-pickle (gh#JoeLametta/whipper#245)
  - credit four major developers by line count
    (gh#JoeLametta/whipper#243)
  - Removed reference to unused "profile = flac" config option
    (gh#JoeLametta/whipper#99, gh#JoeLametta/whipper#231)
- Fixed bugs:
  - ImportError: libcdio.so.16: cannot open shared object file: No
    such file or directory (gh#JoeLametta/whipper#229)
  - whipper offset find exception (gh#JoeLametta/whipper#208)
  - cd rip is not able to rip the last track
    (gh#JoeLametta/whipper#203)
  - whipper not picking up all settings in whipper.conf
    (gh#JoeLametta/whipper#99)
  - fix CI build error with latest pycdio
    (gh#JoeLametta/whipper#233)
- Closed issues:
  - CD-ROM powers off during rip command
    (gh#JoeLametta/whipper#189)
  - GUI frontend for whipper (gh#JoeLametta/whipper#40)
- Merged pull requests:
  - Remove reference to Copr repository
    (gh#JoeLametta/whipper#248)
  - Revert "Convert docstrings to reStructuredText"
    (gh#JoeLametta/whipper#246)
  - remove radon reports (gh#JoeLametta/whipper#242)
  - read command parameters from config sections
    (gh#JoeLametta/whipper#240)
